@@ -1,14 +1,21 @@
+import re
 from lxml import html
 from util import force_decode
 
-def html_minify(html_code):
+def drop_comments(content):
+    comment_regexes = re.compile('<!--(.|\s)*?-->')
+    return comment_regexes.sub('', content)
+
+def html_minify(html_code, ignore_comments=True):
     html_code = force_decode(html_code)
     dom = html.fromstring(html_code)
     html_code = html.tostring(dom, method='html', encoding=unicode)
 
     script = False
+    lines = html_code.split('\n')
     minified_lines = []
-    for line in html_code.split('\n'):
+
+    for line in lines:
         if '</script>' in line:
             script = False
 
@@ -21,7 +28,14 @@ def html_minify(html_code):
 
         if '<script' in line:
             script = True
-            first = True
             minified_lines.append('\n')
 
-    return "".join(minified_lines)
+    content = "".join(minified_lines)
+
+    if "DOCTYPE" not in content:
+        content = "<!DOCTYPE html>%s" % content
+
+    if ignore_comments:
+        content = drop_comments(content)
+
+    return content
